@@ -144,7 +144,7 @@ def prereceive_cmd(ctx: click.Context, web: bool, prereceive_args: List[str]) ->
                 commit_list=commit_list,
                 output_handler=ctx.obj["output_handler"],
                 verbose=config.verbose,
-                filter_set=ctx.obj["filter_set"],
+                exclusion_regexes=ctx.obj["exclusion_regexes"],
                 matches_ignore=config.matches_ignore,
                 all_policies=config.all_policies,
                 scan_id=" ".join(commit_list),
